//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id$
//

#include "ExN01DetectorConstruction.hh"

#include "G4Material.hh"
#include "G4NistManager.hh"
#include "G4Box.hh"
#include "G4LogicalVolume.hh"
#include "G4VisAttributes.hh"
#include "G4ThreeVector.hh"
#include "G4PVPlacement.hh"
#include "G4SystemOfUnits.hh"

ExN01DetectorConstruction::ExN01DetectorConstruction()
{
}

ExN01DetectorConstruction::~ExN01DetectorConstruction()
{
}

G4VPhysicalVolume* ExN01DetectorConstruction::Construct()
{
    
  G4Material* material = G4NistManager::Instance()->FindOrBuildMaterial("G4_WATER");

    G4Box * world_box = new G4Box("world_box", 6.0*cm, 3.0*cm, 3.0*cm);
    G4LogicalVolume * world_log = new G4LogicalVolume(world_box, material,"world_log");
    G4VPhysicalVolume * world_phys = new G4PVPlacement(0,G4ThreeVector(), world_log,"world",0,false,0);
    
    G4Box * cuve_box = new G4Box("cuve_box", 3.0*cm, 3.0*cm, 3.0*cm);
    G4LogicalVolume * cuve_log = new G4LogicalVolume(cuve_box, material,"cuve_log");
    cuve_log->SetVisAttributes( new G4VisAttributes(G4Colour::Cyan()));
    new G4PVPlacement(0,G4ThreeVector(), cuve_log,"cuve",world_log,false,0);
    
    G4Box * interface_box = new G4Box("interface_box", 0.5*cm, 3.0*cm, 3.0*cm);
    G4LogicalVolume * interface_log = new G4LogicalVolume(interface_box, material,"interface_log");
    interface_log->SetVisAttributes( new G4VisAttributes(G4Colour::Blue()));
    new G4PVPlacement(0,G4ThreeVector(), interface_log,"interface",cuve_log,false,0);
     
  return world_phys;
}

