//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id$
//
// 

#include "ExN01PhysicsList.hh"
#include "G4ParticleTypes.hh"
// gamma
#include "G4ComptonScattering.hh"
#include "G4LivermoreComptonModel.hh"
#include "G4PhotoElectricEffect.hh"
#include "G4GammaConversion.hh"
#include "G4RayleighScattering.hh"
// e-
#include "G4eMultipleScattering.hh"
#include "G4UrbanMscModel96.hh"
#include "G4eIonisation.hh"
#include "G4eBremsstrahlung.hh"
// e+
#include "G4eplusAnnihilation.hh"

#include "G4PhysicsListHelper.hh"
#include "G4UAtomicDeexcitation.hh"
#include "G4LossTableManager.hh"
#include "G4ProcessManager.hh"
#include "G4EmProcessOptions.hh"


ExN01PhysicsList::ExN01PhysicsList()
{;}

ExN01PhysicsList::~ExN01PhysicsList()
{;}

void ExN01PhysicsList::ConstructParticle()
{
  G4Gamma::Definition();
  G4Electron::Definition();
  G4Positron::Definition();
 
}

void ExN01PhysicsList::ConstructProcess()
{

  AddTransportation();
      
    theParticleIterator->reset();
    
    while( (*theParticleIterator)() )
    {
        
        G4ParticleDefinition* particle = theParticleIterator->value();
        G4ProcessManager* pmanager = particle->GetProcessManager();
       
        G4String particleName = particle->GetParticleName();
        //G4cout << "PARTICLE NAME : <" << particleName << ">" << G4endl;
        
        if (particle == G4Gamma::Gamma()) {
            G4ComptonScattering * theComptonScattering = new G4ComptonScattering();
            G4LivermoreComptonModel * theLivermoreComptonModel = new G4LivermoreComptonModel();
            theLivermoreComptonModel->SetHighEnergyLimit(GeV);
            theComptonScattering->SetEmModel(theLivermoreComptonModel);
            pmanager->AddDiscreteProcess(theComptonScattering);
            /*
            pmanager->AddDiscreteProcess(new G4RayleighScattering);
            pmanager->AddDiscreteProcess(new G4PhotoElectricEffect);
            pmanager->AddDiscreteProcess(new G4GammaConversion);
            
        }else if (particle == G4Electron::Definition()) {
            G4eMultipleScattering * msc = new G4eMultipleScattering();
            msc -> AddEmModel(0, new G4UrbanMscModel96());
            pmanager->AddDiscreteProcess(msc);

            G4eIonisation* eIoni = new G4eIonisation();
            eIoni->SetStepFunction(0.1, 100*um);
            pmanager->AddDiscreteProcess(eIoni);

            pmanager->AddDiscreteProcess(new G4eBremsstrahlung());
        } else if (particle == G4Positron::Definition()) {
            G4eMultipleScattering * msc = new G4eMultipleScattering();
            msc -> AddEmModel(0, new G4UrbanMscModel96());
            pmanager->AddDiscreteProcess(msc);
            
            G4eIonisation* eIoni = new G4eIonisation();
            eIoni->SetStepFunction(0.1, 100*um);
            pmanager->AddDiscreteProcess(eIoni);
            
            pmanager->AddDiscreteProcess(new G4eBremsstrahlung());
            
            pmanager->AddDiscreteProcess(new G4eplusAnnihilation());  
            */ 
        }
         
    }

    
}

void ExN01PhysicsList::SetCuts()
{
  // uppress error messages even in case e/gamma/proton do not exist            
  G4int temp = GetVerboseLevel();
    SetVerboseLevel(0);
  //  " G4VUserPhysicsList::SetCutsWithDefault" method sets 
  //   the default cut value for all particle types 
  SetCutsWithDefault();

  // Retrieve verbose level
  SetVerboseLevel(temp);  
}

